--[[
core = AceLibrary("AceAddon-2.0"):new("AceDB-2.0", "AceConsole-2.0", "AceModuleCore-2.0")
core:RegisterDB("SimpleUnitFramesDB")
core:RegisterDefaults('profile', {
	a = 1
} )
core:RegisterChatCommand( {'/core'}, {
	type = 'group',
	args = {}
} )

if true then return end
]]

local SUF = AceLibrary("AceAddon-2.0"):new("AceModuleCore-2.0", "AceDB-2.0", "AceConsole-2.0")

SUF.modulePrototype.core = SUF

SUF.defaults = {}

function SUF:OnInitialize()

	self:RegisterDB("SimpleUnitFramesDB", "SimpleUnitFramesDBPerChar")
	-- self:RegisterDefaults('profile', self.defaults)

	local consoleOptions = {
		type = 'group',
		args = {}
	}

	local defaultOptions = {
		a = 1,
		b = 2
	}

	self:RegisterDefaults('profile', defaultOptions)
	self:RegisterChatCommand( { '/suf' }, consoleOptions )
	
	-- This only works after RegisterChatCommand().
	consoleOptions.args.standby = nil
	
	for name, module in self:IterateModules() do
		if module.GetConsoleOptions then
			consoleOptions.args[name] = module:GetConsoleOptions()
		end
	end

	
end

function SUF.modulePrototype:GetValueText(unitid, style)
	if not SUF.styles[style] then return "ERROR" end
	return SUF.styles[style](unitid)
end


SUF.formatList = {
	"currmaxhp", "percenthp", "completehp", "deficithp", "mh3completehp", 
	"currmaxmp", "percentmp", "completemp", "deficitmp",
	"none",	
}

SUF.styles = {

	["currmaxhp"] = function(unitid) 
		return UnitHealth(unitid) .. '/' .. UnitHealthMax(unitid) 
	end,
	
	["percenthp"] = function(unitid) 
		return string.format( "%d%%", UnitHealth(unitid) * 100 / UnitHealthMax(unitid) ) 
	end,
	
	["completehp"] = function(unitid) 
		local curr, max = UnitHealth(unitid), UnitHealthMax(unitid)
		local percent = curr*100/max
		if max == 100 then -- Only return % when the exact HP is not know.
			return string.format( "(%d%%)", percent )
		else
			return string.format( "%d/%d (%d%%)", curr, max, percent)
		end
	end,
	
	["deficithp"] = function(unitid)
		return UnitHealth(unitid) - UnitHealthMax(unitid)
	end,
	
	["mh3completehp"] = function(unitid)
		local curr, max
		if MobHealth3 then
			curr, max = MobHealth3:GetUnitHealth(unitid)
		else
			curr, max = UnitHealth(unitid), UnitHealthMax(unitid)
		end
		local percent = curr*100/max
		if max == 100 then -- Only return % when the exact HP is not know.
			return string.format( "(%d%%)", percent )
		else
			return string.format( "%d/%d (%d%%)", curr, max, percent)
		end
	end,

	["currmaxmp"] = function(unitid) 
		return UnitMana(unitid) .. '/' .. UnitManaMax(unitid) 
	end,
	
	["percentmp"] = function(unitid) 
		return string.format( "%d%%", UnitMana(unitid) * 100 / UnitManaMax(unitid) ) 
	end,
	
	["completemp"] = function(unitid) 
		local curr, max = UnitMana(unitid), UnitManaMax(unitid)
		return string.format( "%d/%d (%d%%)", curr, max, curr*100/max)
	end,

	["deficitmp"] = function(unitid)
		return UnitMana(unitid) - UnitManaMax(unitid)
	end,
	
	["none"] = function() return "" end,
	
}

setglobal('SimpleUnitFrames', SUF)